"""Quick code snippets for embedding IPython into other programs.

See example-embed.py for full details, this file has the bare minimum code for
cut and paste use once you understand how to use the system."""

#---------------------------------------------------------------------------
# This code loads IPython but modifies a few things if it detects it's running
# embedded in another IPython session (helps avoid confusion)

# Command-line options for IPython (no quotes, %s for spaces)
argv = ''
try:
    if __IPYTHON__:
        # Remember not to use quotes and to use %s to represent spaces:
        nested = "-pi1 In%s<%n>: -po Out<%n>:"
        banner = '*** Nested interpreter ***'
        exit_msg = '*** Back in main IPython ***'
except:
    nested = banner = exit_msg = ''

# First import the embeddable shell class
from IPython.Shell import IPythonShellEmbed
ipshell = IPythonShellEmbed(argv+' '+nested,banner=banner,exit_msg=exit_msg)
                            
    
#---------------------------------------------------------------------------
# This code will load an embeddable IPython shell always with no changes for
# nested embededings.

from IPython.Shell import IPythonShellEmbed
ipshell = IPythonShellEmbed()
# Now ipshell() will open IPython anywhere in the code.

#---------------------------------------------------------------------------
# This code loads an embeddable shell only if NOT running inside
# IPython. Inside IPython, the embeddable shell variable ipshell is just a
# dummy function.

try:
    __IPYTHON__
except:
    from IPython.Shell import IPythonShellEmbed
    ipshell = IPythonShellEmbed()
    # Now ipshell() will open IPython anywhere in the code
else:
    # Define a dummy ipshell() so the same code doesn't crash inside an
    # interactive IPython
    def ipshell(): pass

#******************* End of file <example-embed-short.py> ********************
