#!/usr/bin/env python
"""
Example code showing how to use gnuplot and an embedded IPython shell.
"""

import Gnuplot
from Numeric import *
from IPython.numutils import *
from IPython.Shell import IPythonShellEmbed

# Arguments to start IPython shell with. Load numeric profile.
ipargs = '-profile numeric' 
ipshell = IPythonShellEmbed(ipargs)

# Compute sin(x) over the 0..2pi range at 100 points
x = frange(0,2*pi,npts=200)
y = sin(x)

# Make a gnuplot instance
g2 = Gnuplot.Gnuplot()

# Change some defaults
g2('set data style lines')

# Or also call a multi-line set of gnuplot commands on it:
gnuplot_exec(g2,"""
set xrange [0:pi]     # Set the visible range to half the data only
set title 'Half sine' # Global gnuplot labels
set xlabel 'theta'
set ylabel 'sin(theta)'
""")

# Set the gnuplot instance accessed by @gp to our customized one. This way the
# interactive system @gp will see our instance with whatever changes we've
# made to it.
ipshell.IP.gnuplot = g2

# Now start an embedded ipython. g2 is a visible global, but it's also the one
# accessed by @gp now
ipshell('Starting the embedded IPyhton.\n'
        'Try calling g2.plot(zip(x,y)), or "@gp plot x**2"\n')

#********************** End of file <example-gnuplot.py> *********************
